The US Social Security Number (SSN) is a personally identifiable
number that is issued to its citizens.

A stolen or leaked SSN can
lead to a compromise, and/or the theft of the affected individual's
identity.

Through the use of regular expressions, the tool has
discovered an SSN located within the response of the affected page.